@@ -8,50 +8,8 @@ Penman-Monteith equation is used to calculate reference crop evapotranspiration
 for a given location using available climate data. This method provides many ways of estimating
 missing climate data using minimal data.
 
-Following are the least data required to estimate ETo:
+@author: sherzodr@gmail.com
 
-    * latitude
-    * elevation
-    * date
-    * daily minimum temperature
-    * daily maximum temperature
-
-It can do this by making certain assumptions about the climate conditions. These assumptions
-can be fine-tuned. **Climate** is responsible for setting these assumptions.
-
-Following is the simplest code that is possible using the module:
-
-    import penmon.eto as pm
-    
-    station = pm.Station(latitude=41.42, altitude=109)
-    day = station.get_day(238)
-    day.temp_min = 19.5
-    day.temp_max = 25.6
-    
-    print("ETo for this day is", day.eto)
-
-By default it assumes we are in *arid, interior location, with moderate winds*. To adjust these assumptions you can define
-your own Climate() class and assign this instance to the station:
-
-    humid_climate = pm.Climate().humid().coastal().strong_winds()
-
-    station = pm.Station(41.42, 109)
-    station.climate = climate
-    
-If you do not want it to make any assumptions about its climate you may set *climate* attribute
-of the Station to *None*:
-
-    station = pm.Station(41.42, 109)
-    station.climate = None
-
-In this case, if humidity and wind information are missing, instead of trying to guess missing data
-it relies on Haargresves' ETo equation (Eq 52). 
-
-Whenever appropriate reference to Equations used in UN-FAO Paper 56 are made.
-
-AUTHOR
-
-    Sherzod Ruzmetov <sherzodr@gmail.com>
 """
 import math
 import datetime as dt
@@ -112,7 +70,7 @@ class Station:
         """ See get_day()"""
         return self.get_day(day_number)
     
-    def get_day(self, day_number, strp_template="%Y-%m-%d"):
+    def get_day(self, day_number, date_template="%Y-%m-%d", temp_min=None, temp_max=None, wind_speed=None, humidity_mean=None, radiation_s=None):
         """
         Given a day number (integer type from 1-366) returns a **StationDay*** instance for 
         that day. Logs the day in *days* attribute of the **Station()** class.
@@ -121,7 +79,7 @@ class Station:
         it parses the string into **datetime** and calculates day number
         
         
-        If your date format is different than assumed, you can adjust *strp_template* 
+        If your date format is different than assumed, you can adjust *date_template* 
         as the second parameter. For example, following all three lines are identical
         
             day = station.get_day(229)
@@ -131,7 +89,7 @@ class Station:
 
         if type(day_number) is str:
             try:
-                dt1 = dt.datetime.strptime(day_number, strp_template)
+                dt1 = dt.datetime.strptime(day_number, date_template)
             except ValueError:
                 raise ValueError("Date must be in YYYY-MM-DD format (ex: 2020-09-28)")
 
@@ -146,7 +104,14 @@ class Station:
             raise Exception("'day_number' must be between in the range 1-366")
 
         day = StationDay(day_number, self)
+
         self.days[day_number] = day
+        day.temp_min=temp_min
+        day.temp_max=temp_max
+        day.humidity_mean=humidity_mean
+        day.wind_speed=wind_speed
+        day.radiation_s=radiation_s
+
         return day;
 
     def describe(self):
